@@ -10,7 +10,7 @@ from ..mixtures import (
     CompositionType,
     Mixture,
     Mixtures,
-    get_nrtl_partial_pressures,
+    get_partial_pressures,
 )
 from ..permeance import Permeance, Units
 from ..plotting import plot_graph
@@ -61,9 +61,7 @@ class DiffusionCurve:
             :return a list of Partial fluxes for each component tuple(Ji,Jj) at each concentration
             """
             feed_partial_pressures = [
-                get_nrtl_partial_pressures(
-                    self.feed_temperature, self.mixture, composition
-                )
+                get_partial_pressures(self.feed_temperature, self.mixture, composition)
                 for composition in self.feed_compositions
             ]
 
@@ -98,9 +96,7 @@ class DiffusionCurve:
             """
             permeate_compositions = self.permeate_composition
             feed_partial_pressures = [
-                get_nrtl_partial_pressures(
-                    self.feed_temperature, self.mixture, composition
-                )
+                get_partial_pressures(self.feed_temperature, self.mixture, composition)
                 for composition in self.feed_compositions
             ]
             if self.permeate_temperature is None and self.permeate_pressure is None:
@@ -121,7 +117,7 @@ class DiffusionCurve:
                 self.permeate_temperature is not None and self.permeate_pressure is None
             ):
                 permeate_partial_pressures = [
-                    get_nrtl_partial_pressures(
+                    get_partial_pressures(
                         self.permeate_temperature, self.mixture, composition
                     )
                     for composition in permeate_compositions
@@ -307,7 +303,8 @@ class DiffusionCurve:
         return list(numpy.multiply(total_flux, numpy.subtract(separation_factor, 1)))
 
     @property
-    def get_permeances(self) -> typing.List[typing.Tuple[Permeance, Permeance]]:
+    def get_permeances(self, calculation_type: typing.Optional[str] = "NRTL")\
+            -> typing.List[typing.Tuple[Permeance, Permeance]]:
         """
         Calculates permenace of both components based on the partial flux values, mixture, feed  and permeate parameters
         :return: Permeances of each component at each feed concentration as [(P1,P2),...]
@@ -317,9 +314,7 @@ class DiffusionCurve:
         else:
             permeate_compositions = self.permeate_composition
             feed_partial_pressures = [
-                get_nrtl_partial_pressures(
-                    self.feed_temperature, self.mixture, composition
-                )
+                get_partial_pressures(self.feed_temperature, self.mixture, composition, calculation_type)
                 for composition in self.feed_compositions
             ]
             if self.permeate_temperature is None:
@@ -338,8 +333,8 @@ class DiffusionCurve:
                 ]
             else:
                 permeate_partial_pressures = [
-                    get_nrtl_partial_pressures(
-                        self.permeate_temperature, self.mixture, composition
+                    get_partial_pressures(
+                        self.permeate_temperature, self.mixture, composition, calculation_type
                     )
                     for composition in permeate_compositions
                 ]
